@@ -396,7 +396,7 @@ def get_connections(network, id, skip, take, show_services, json, platform):
         ("Status", "agent_connection_status"),
         ("Network name", "network_name"),
         ("Network type", "network_type"),
-        ("Network ID", "network_id"),
+        ("Network ID", ("network", "network_id")),
         ("Gateway ID", "agent_gateway_id"),
         ("Created At", "agent_connection_created_at"),
         ("Modified At", "agent_connection_modified_at"),
@@ -806,7 +806,7 @@ def export_networks(network, skip, take, topology, to_json, platform):
                 ),
             }
             for connection in connections
-            if connection["network_id"] == net["id"]
+            if connection["network"]["network_id"] == net["id"]
         ]
         transformed_connections = transform_connections(
             all_agents,
