@@ -899,7 +899,7 @@ def configure_network_delete(api, network, dry_run, silent=False):
         filter=f"networks[]:{network['id']}", take=TAKE_MAX_ITEMS_PER_CALL
     )
     for connection in connections["data"]:
-        if connection["network_id"] != network["id"]:
+        if connection["network"]["network_id"] != network["id"]:
             continue
         if dry_run:
             not silent and click.echo(
@@ -979,7 +979,7 @@ def configure_network_update(api, network, config, dry_run, silent=False):
     connections = [
         connection
         for connection in connections
-        if connection["network_id"] == network[ConfigFields.ID]
+        if connection["network"]["network_id"] == network[ConfigFields.ID]
     ]
     all_agents = get_all_agents(api, silent)
     resolved_connections = transform_connections(
@@ -990,7 +990,9 @@ def configure_network_update(api, network, config, dry_run, silent=False):
         silent=silent,
     )
     current_connections = {
-        frozenset((connection["agent_1_id"], connection["agent_2_id"])): connection
+        frozenset(
+            (connection["agent_1"]["agent_id"], connection["agent_2"]["agent_id"])
+        ): connection
         for connection in connections
     }
     config_connections = config.get(ConfigFields.CONNECTIONS, {})
